##  Relation Mapping Parameters
Parameter | Description
---|---
Source System | System that serves as the source of truth for the relation (SAP LeanIX or Jira Service Management)
From Fact Sheet Mapping | Previously configured fact sheet mapping representing the source endpoint
To Fact Sheet Mapping | Previously configured fact sheet mapping representing the target endpoint
SAP LeanIX Relation Type | Relation type in SAP LeanIX
Jira Service Management Relation Type | Reference relation type in Jira Service Management
Direction | Synchronization direction (determined by the source system selection)


